==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/bathroom/dialogs_es.lua <==

dialogId("br-v-komfort", "font_big", "It`s quite comfortable for a wasteyard.")
dialogStr("Bastante confortable para un basural.")


dialogId("br-m-bydli", "font_small", "What do you think, does anybody live here?")
dialogStr("¿Qué piensas, vivirá alguien aquí?")


dialogId("br-v-santusak", "font_big", "Some underwater homeless.")
dialogStr("Algún vago sin hogar submarino.")


dialogId("br-m-podvodnik", "font_small", "We call them shell-less.")
dialogStr("Nosotros los llamamos \"Sin concha\".")


dialogId("br-m-vsim0", "font_small", "Did you notice that...")
dialogStr("Notaste que...")


dialogId("br-m-vsim1", "font_small", "Don`t you think that...")
dialogStr("No piensas que...")


dialogId("br-m-vsim2", "font_small", "Isn`t it strange that...")
dialogStr("No es extraño que...")


dialogId("br-v-nerozvadet0", "font_big", "Don`t talk about it.")
dialogStr("No hables de eso.")


dialogId("br-v-nerozvadet1", "font_big", "Please, no jokes about defecation.")
dialogStr("Por favor, sin bromas sobre defecación.")


dialogId("br-v-nerozvadet2", "font_big", "Yes, I know about that. We won`t comment on it.")
dialogStr("Si, conozco eso. Sin comentarios.")


dialogId("br-m-dva", "font_small", "Yeah, but why TWO?")
dialogStr("¿Si, pero porqué DOS?")


dialogId("br-v-dost", "font_big", "Stop it, will you?")
dialogStr("¿¡Basta, quieres!?")


dialogId("br-m-sprcha", "font_small", "I`ve seen many useless things, but an underwater shower...")
dialogStr("He visto muchas cosas inútiles, pero una ducha submarina...")


dialogId("br-v-lazen", "font_big", "Maybe it sprays air, like in the bubble bath.")
dialogStr("Quizás tira aire, como un baño de burbujas.")


dialogId("br-m-zapnout", "font_small", "Do you think we could turn it on?")
dialogStr("¿Crees que podamos encenderlo?")


dialogId("br-v-shodit", "font_big", "Hardly. But we could push it down.")
dialogStr("Lo dudo. Pero podríamos tirarlo hacia abajo.")


dialogId("br-m-poklady", "font_small", "Now this is real treasure.")
dialogStr("Ahora este si que es un tesoro.")


dialogId("br-v-nechat", "font_big", "We should have left it alone.")
dialogStr("Deberíamos de haberlo dejado solo.")


dialogId("br-m-nefunguje", "font_small", "And it doesn`t work anyway.")
dialogStr("Y no funciona de todas formas.")


dialogId("br-m-ahoj", "font_small", "Hello, inside there.")
dialogStr("Hola, ahi adentro.")


dialogId("br-v-draha", "font_big", "This must be better than a rollercoaster.")
dialogStr("Esto debe ser mejor que una montaña rusa.")


dialogId("br-m-zkusit", "font_small", "I would love to try it myself.")
dialogStr("Me gustaría intentarlo yo mismo.")


dialogId("br-m-bavi", "font_small", "He seems to be enjoying himself.")
dialogStr("Parece estar disfrutándolo.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/bathroom/dialogs_es.lua <==

dialogId("br-v-komfort", "font_big", "It’s quite comfortable for a wasteyard.")
dialogStr("Bastante confortable para un basural.")


dialogId("br-m-bydli", "font_small", "What do you think, does anybody live here?")
dialogStr("¿Qué piensas, vivirá alguien aquí?")


dialogId("br-v-santusak", "font_big", "Some underwater homeless.")
dialogStr("Algún vago sin hogar submarino.")


dialogId("br-m-podvodnik", "font_small", "We call them shell-less.")
dialogStr("Nosotros los llamamos \"Sin concha\".")


dialogId("br-m-vsim0", "font_small", "Did you notice that...")
dialogStr("Notaste que...")


dialogId("br-m-vsim1", "font_small", "Don’t you think that...")
dialogStr("No piensas que...")


dialogId("br-m-vsim2", "font_small", "Isn’t it strange that...")
dialogStr("No es extraño que...")


dialogId("br-v-nerozvadet0", "font_big", "Don’t talk about it.")
dialogStr("No hables de eso.")


dialogId("br-v-nerozvadet1", "font_big", "Please, no jokes about defecation.")
dialogStr("Por favor, sin bromas sobre defecación.")


dialogId("br-v-nerozvadet2", "font_big", "Yes, I know about that. We won’t comment on it.")
dialogStr("Si, conozco eso. Sin comentarios.")


dialogId("br-m-dva", "font_small", "Yeah, but why TWO?")
dialogStr("¿Si, pero porqué DOS?")


dialogId("br-v-dost", "font_big", "Stop it, will you?")
dialogStr("¿¡Basta, quieres!?")


dialogId("br-m-sprcha", "font_small", "I’ve seen many useless things, but an underwater shower...")
dialogStr("He visto muchas cosas inútiles, pero una ducha submarina...")


dialogId("br-v-lazen", "font_big", "Maybe it sprays air, like in the bubble bath.")
dialogStr("Quizás tira aire, como un baño de burbujas.")


dialogId("br-m-zapnout", "font_small", "Do you think we could turn it on?")
dialogStr("¿Crees que podamos encenderlo?")


dialogId("br-v-shodit", "font_big", "Hardly. But we could push it down.")
dialogStr("Lo dudo. Pero podríamos tirarlo hacia abajo.")


dialogId("br-m-poklady", "font_small", "Now this is real treasure.")
dialogStr("Ahora este si que es un tesoro.")


dialogId("br-v-nechat", "font_big", "We should have left it alone.")
dialogStr("Deberíamos de haberlo dejado solo.")


dialogId("br-m-nefunguje", "font_small", "And it doesn’t work anyway.")
dialogStr("Y no funciona de todas formas.")


dialogId("br-m-ahoj", "font_small", "Hello, inside there.")
dialogStr("Hola, ahi adentro.")


dialogId("br-v-draha", "font_big", "This must be better than a rollercoaster.")
dialogStr("Esto debe ser mejor que una montaña rusa.")


dialogId("br-m-zkusit", "font_small", "I would love to try it myself.")
dialogStr("Me gustaría intentarlo yo mismo.")


dialogId("br-m-bavi", "font_small", "He seems to be enjoying himself.")
dialogStr("Parece estar disfrutándolo.")
